summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /kmail/kmfoldercachedimap.h
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index bd084f00..a25637b3 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -285,8 +285,8 @@ public:
void setACLList( const ACLList& arr );
// Reimplemented so the mStatusChangedLocally bool can be set
- virtual void seStatus( int id, KMMsgStatus status, bool toggle );
- virtual void seStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
+ virtual void setStatus( int id, KMMsgStatus status, bool toggle );
+ virtual void setStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
TQString annotationFolderType() const { return mAnnotationFolderType; }
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
* UIDs added by seStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status
* of the mails in this folder.
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
- * UIDs added by seStatus. Indicates that the client has changed
+ * UIDs added by setStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status